@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: machine.h,v 1.37 2004/07/06 19:17:56 abe Exp $
+ * $Id: machine.h,v 1.38 2004/10/17 21:54:50 abe Exp $
  */
 
 
@@ -413,10 +413,21 @@
 /*
  * HASSETLOCALE is defined for those dialects that have <locale.h> and
  * setlocale().
+ *
+ * If the dialect also has wide character support for language locales,
+ * HASWIDECHAR activates lsof's wide character support and WIDECHARINCL
+ * defines the header file (if any) that must be #include'd to use the
+ * mblen() and mbtowc() functions.
  */
 
 #define	HASSETLOCALE	1
 
+# if	DUV>=40000
+#define	HASWIDECHAR	1
+# endif	/* DUV>=40000 */
+
+/* #define	WIDECHARINCL	<wchar.h>	*/
+
 
 /*
  * HASSNODE is defined for those dialects that have snodes.
