@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.34 2004/07/06 19:18:57 abe Exp $
+ * $Id: dlsof.h,v 1.35 2004/10/17 21:57:28 abe Exp $
  */
 
 
@@ -261,7 +261,13 @@ struct vop_generic_args;
 
 # if	defined(DTYPE_KQUEUE)
 #define	HASKQUEUE				/* has the kqueue file type */
+#   if	FREEBSDV>=4090
+#define	_KERNEL
+#   endif	/* FREEBSDV>=4090 */
 #include <sys/eventvar.h>
+#   if	FREEBSDV>=4090
+#undef	_KERNEL
+#   endif	/* FREEBSDV>=4090 */
 # endif	/* defined(DTYPE_KQUEUE) */
 
 # if	FREEBSDV<2000
@@ -282,7 +288,13 @@ struct vop_advlock_args { int dummy; };	/* to pacify lf_advlock() prototype */
 #include <vm/vm.h>
 
 #  if   FREEBSDV>=2020
+#   if	FREEBSDV>=4090
+#define	_KERNEL
+#   endif	/* FREEBSDV>=4090 */
 #include <sys/pipe.h>
+#   if	FREEBSDV>=4090
+#undef	_KERNEL
+#   endif	/* FREEBSDV>=4090 */
 #   if	defined(HASVMLOCKH)
 #include <vm/lock.h>
 #   endif	/* defined(HASVMLOCKH) */
