@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dsock.c,v 1.25 2004/07/06 19:19:44 abe Exp $";
+static char *rcsid = "$Id: dsock.c,v 1.26 2004/10/17 21:57:43 abe Exp $";
 #endif
 
 
@@ -110,6 +110,10 @@ struct uxsin {				/* UNIX socket information */
 	unsigned long inode;
 	char *pcb;
 	char *path;
+	unsigned char sb_def;
+	dev_t sb_dev;
+	unsigned long sb_ino;
+	dev_t sb_rdev;
 	struct uxsin *next;
 };
 
@@ -1363,7 +1367,26 @@ get_unix(p)
 	    }
 	    up->inode = inode;
 	    up->pcb = pcb;
-	    up->path = path;
+	    up->sb_def = 0;
+	    if ((up->path = path) && (*path == '/')) {
+
+	    /*
+	     * If an absolute path (i.e., one that begins with a '/') exists
+	     * for the line, attempt to stat(2) it and save the device and
+	     * node numbers reported in the stat buffer.
+	     */
+		struct stat sb;
+
+		if (((HasNFS && !statsafely(path, &sb))
+		||   (!HasNFS && !stat(path, &sb)))
+		&&  ((sb.st_mode & S_IFMT) == S_IFSOCK)
+		) {
+		    up->sb_def = 1;
+		    up->sb_dev = sb.st_dev;
+		    up->sb_ino = (unsigned long)sb.st_ino;
+		    up->sb_rdev = sb.st_rdev;
+		}
+	    }
 	    up->next = Uxsin[h];
 	    Uxsin[h] = up;
 	}
@@ -1788,10 +1811,66 @@ process_proc_sock(p, s, ss, l, lss)
 	    }
 	    path = up->path ? up->path : p;
 	    (void) enter_nm(path);
-	    if (Sfile && is_file_named(path,
-		((ss & SB_MODE) && ((s->st_mode & S_IFMT) == S_IFCHR)) ? 1 : 0))
-	    {
-		Lf->sf |= SELNM;
+	    if (Sfile) {
+	    
+	    /*
+	     * See if this UNIX domain socket was specified as a search
+	     * argument.
+	     *
+	     * Search first by device and node numbers, if that is possible;
+	     * then search by name.
+	     */
+		unsigned char f = 0;		/* file-found flag */
+
+		if (up->sb_def) {
+
+		/*
+		 * If the UNIX socket information includes stat(2) results, do
+		 * a device and node number search.
+		 *
+		 * Note: that requires the saving, temporary modification and
+		 *	 restoration of some *Lf values.
+		 */
+		    unsigned char sv_dev_def;	/* saved dev_def */
+		    unsigned char sv_inp_ty;	/* saved inp_ty */
+		    unsigned char sv_rdev_def;	/* saved rdev_def */
+		    dev_t sv_dev;		/* saved dev */
+		    unsigned long sv_inode;	/* saved inode */
+		    dev_t sv_rdev;		/* saved rdev */
+
+		    sv_dev_def = Lf->dev_def;
+		    sv_dev = Lf->dev;
+		    sv_inode = Lf->inode;
+		    sv_inp_ty = Lf->inp_ty;
+		    sv_rdev_def = Lf->rdev_def;
+		    sv_rdev = Lf->rdev;
+		    Lf->dev_def = Lf->inp_ty = Lf->rdev_def = 1;
+		    Lf->dev = up->sb_dev;
+		    Lf->inode = up->sb_ino;
+		    Lf->rdev = up->sb_rdev;
+		    if (is_file_named((char *)NULL, 0)) {
+			f = 1;
+			Lf->sf |= SELNM;
+		    }
+		    Lf->dev_def = sv_dev_def;
+		    Lf->dev = sv_dev;
+		    Lf->inode = sv_inode;
+		    Lf->inp_ty = sv_inp_ty;
+		    Lf->rdev_def = sv_rdev_def;
+		    Lf->rdev = sv_rdev;
+		}
+		if (!f && (ss & SB_MODE)) {
+
+		/*
+		 * If the file has not yet been found and the stat buffer has
+		 * st_mode, search for the file by full path.
+		 */
+		    if (is_file_named(path,
+			((s->st_mode & S_IFMT) == S_IFCHR)) ? 1 : 0)
+		    {
+			Lf->sf |= SELNM;
+		    }
+		}
 	    }
 	    return;
 	}
