@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: proc.c,v 1.36 2004/03/10 23:44:14 abe Exp $";
+static char *rcsid = "$Id: proc.c,v 1.37 2004/10/17 21:39:23 abe Exp $";
 #endif
 
 
@@ -123,11 +123,11 @@ alloc_fflbuf(bp, al, lr)
 
 void
 alloc_lfile(nm, num)
-	char *nm;
-	int num;
+	char *nm;			/* file descriptor name (may be NULL) */
+	int num;			/* file descriptor number -- -1 if
+					 * none */
 {
-	char *cp;
-	struct fd_lst *fp;
+	int fds;
 
 	if (Lf) {
 /*
@@ -239,41 +239,15 @@ alloc_lfile(nm, num)
  */
 	if (!Fdl || (!nm && num < 0))
 	    return;
-	if ((cp = nm)) {
-	    while (*cp && *cp == ' ')
-		cp++;
-	}
-/*
- * Check for an exclusion match.
- */
-	if (FdlTy == 1) {
-	    for (fp = Fdl; fp; fp = fp->next) {
-		if (cp) {
-		    if (fp->nm && strcmp(fp->nm, cp) == 0)
-			return;
-		    continue;
-		}
-		if (num >= fp->lo && num <= fp->hi)
-		    return;
-	    }
-	    Lf->sf |= SELFD;
-	    return;
-	}
-/*
- * If Fdl isn't an exclusion list, check an inclusion match.
- */
-	for (fp = Fdl; fp; fp = fp->next) {
-	    if (cp) {
-		if (fp->nm && strcmp(fp->nm, cp) == 0) {
-		    Lf->sf |= SELFD;
-		    return;
-		}
-		continue;
-	    }
-	    if (num >= fp->lo && num <= fp->hi) {
+	fds = ck_fd_status(nm, num);
+	switch (FdlTy) {
+	case 0:			/* inclusion list */
+	    if (fds == 2)
+		Lf->sf |= SELFD;
+	    break;
+	case 1:			/* exclusion list */
+	    if (fds != 1)
 		Lf->sf |= SELFD;
-		return;
-	    }
 	}
 }
 
@@ -343,6 +317,60 @@ alloc_lproc(pid, pgid, ppid, uid, cmd, pss, sf)
 }
 
 
+/*
+ * ck_fd_status() - check FD status
+ *
+ * return: 0 == FD is neither included nor excluded
+ *	   1 == FD is excluded
+ *	   2 == FD is included
+ */
+
+extern int
+ck_fd_status(nm, num)
+	char *nm;			/* file descriptor name (may be NULL) */
+	int num;			/* file descriptor number -- -1 if
+					 * none */
+{
+	char *cp;
+	struct fd_lst *fp;
+
+	if (!(fp = Fdl) || (!nm && num < 0))
+	    return(0);
+	if ((cp = nm)) {
+	    while (*cp && *cp == ' ')
+		cp++;
+	}
+/*
+ * Check for an exclusion match.
+ */
+	if (FdlTy == 1) {
+	    for (; fp; fp = fp->next) {
+		if (cp) {
+		    if (fp->nm && strcmp(fp->nm, cp) == 0)
+			return(1);
+		    continue;
+		}
+		if (num >= fp->lo && num <= fp->hi)
+		    return(1);
+	    }
+	    return(0);
+	}
+/*
+ * If Fdl isn't an exclusion list, check for an inclusion match.
+ */
+	for (; fp; fp = fp->next) {
+	    if (cp) {
+		if (fp->nm && strcmp(fp->nm, cp) == 0)
+		    return(2);
+		continue;
+	    }
+	    if (num >= fp->lo && num <= fp->hi)
+		return(2);
+	}
+	return(0);
+}
+
+
 /*
  * comppid() - compare PIDs
  */
